@@ -143,6 +143,8 @@ int ConsolePlayer::args (int argc, const char *argv[])
     m_driver.file   = false;
     m_driver.sid    = EMU_RESIDFP;
 
+    v1mute = v2mute = v3mute = false;
+
     // parse command line arguments
     while ((i < argc) && (argv[i] != NULL))
     {
@@ -260,6 +262,23 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 m_track.first = atoi(&argv[i][2]);
             }
 
+            // Channel muting
+            else if (argv[i][1] == 'u')
+            {
+                if (argv[i][2] == '\0')
+                    err = true;
+                else
+                {
+                    const int voice = atoi(&argv[i][2]);
+                    switch (voice)
+                    {
+                    case 1: v1mute = true; break;
+                    case 2: v2mute = true; break;
+                    case 3: v3mute = true; break;
+                    }
+                }
+            }
+
             else if (argv[i][1] == 'p')
             {   // User forgot precision
                 if (argv[i][2] == '\0')
@@ -539,6 +558,8 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " -fd          force dual sid environment" << endl
         << " -fs          force samples to a channel (default: uses sid)" << endl
 
+        << "-u<num>       mute voice <num> (e.g. -u1 -u2)" << endl
+
         << " -nf          no SID filter emulation" << endl
         << " -ns[0|1]     (no) MOS 8580 waveforms (default: from tune or cfg)" << endl
 
